import { world, Player, Entity } from '@minecraft/server';
import { ActionFormData, MessageFormData, ModalFormData } from '@minecraft/server-ui';
import { getRandomInt, getScore } from "./Main.js";

export function open_villagerGUI(player) {
	let entity = player.getEntitiesFromViewDirection({maxDistance:3}).map(ray => ray.entity);
	let player_relationship = "relationship_" + player.nameTag;
	let player_flirt = "flirt_" + player.nameTag;
	let relationship = getScore(entity[0], player_relationship);
	let flirt_count = getScore(entity[0], player_flirt);
	if (!world.scoreboard.getObjective(player_relationship)) {
		world.scoreboard.addObjective(player_relationship, player_relationship);
	}
	if (!world.scoreboard.getObjective(player_flirt)) {
		world.scoreboard.addObjective(player_flirt, player_flirt);
	}
	const form = new ActionFormData();
	form.title(entity[0].nameTag);
	if (entity[0].hasTag("energetic") && relationship <= 14) {
		form.body("energetic_villager.chatbubble.1");
	} 
	if (entity[0].hasTag("energetic") && relationship >= 15) {
		form.body("energetic_villager.chatbubble.1_2");
	} 
	if (entity[0].hasTag("flirty") && relationship <= 14) {
		form.body("flirty_villager.chatbubble.1");
	}
	if (entity[0].hasTag("flirty") && relationship >= 15) {
		form.body("flirty_villager.chatbubble.1_2");
	}
	if (entity[0].hasTag("rude") && relationship <= 14) {
		form.body("rude_villager.chatbubble.1");
	}
	if (entity[0].hasTag("rude") && relationship >= 15) {
		form.body("rude_villager.chatbubble.1_2");
	}
	if (entity[0].hasTag("shy") && relationship <= 14) {
		form.body("shy_villager.chatbubble.1");
	}
	if (entity[0].hasTag("shy") && relationship >= 15) {
		form.body("shy_villager.chatbubble.1_2");
	}
	form.button("villager.dialogue.talk");
	form.button("villager.dialogue.trade");
	if (relationship >= 30 && entity[0].hasTag("not_following")) {
		form.button("villager.dialogue.follow");
	}
	if (relationship >= 30 && entity[0].hasTag("following")) {
		form.button("villager.dialogue.stop_following");
	}
	form.show(player).then(response => {
		if (response.selection == 0) {
			open_villager_talkGUI(player);
		}
		if (response.selection == 1) {
			entity[0].runCommandAsync("function trade");
		}
		if (response.selection == 2) {
			if (entity[0].hasTag("not_following")) {
				entity[0].runCommandAsync("function follow");
			} else if (entity[0].hasTag("following")) {
				entity[0].runCommandAsync("function stop_following");
			}
		}
	})
};

function open_villager_talkGUI(player) {
	let entity = player.getEntitiesFromViewDirection({maxDistance:3}).map(ray => ray.entity);
	let player_relationship = "relationship_" + player.nameTag;
	let player_flirt = "flirt_" + player.nameTag;
	let relationship = getScore(entity[0], player_relationship);
	let flirt_count = getScore(entity[0], player_flirt);
	const form = new ActionFormData();
	form.title(entity[0].nameTag);
	if (entity[0].hasTag("energetic") && relationship <= 14) {
		form.body("energetic_villager.chatbubble.2");
	}
	if (entity[0].hasTag("energetic") && relationship >= 15) {
		form.body("energetic_villager.chatbubble.2_2");
	}
	if (entity[0].hasTag("flirty") && relationship <= 14) {
		form.body("flirty_villager.chatbubble.2");
	}
	if (entity[0].hasTag("flirty") && relationship >= 15) {
		form.body("flirty_villager.chatbubble.2_2");
	}
	if (entity[0].hasTag("rude") && relationship <= 14) {
		form.body("rude_villager.chatbubble.2");
	}
	if (entity[0].hasTag("rude") && relationship >= 15) {
		form.body("rude_villager.chatbubble.2_2");
	}
	if (entity[0].hasTag("shy") && relationship <= 14) {
		form.body("shy_villager.chatbubble.2");
	}
	if (entity[0].hasTag("shy") && relationship >= 15) {
		form.body("shy_villager.chatbubble.2_2");
	}
	form.button("villager.dialogue.about_yourself");
	form.button("villager.dialogue.talk");
	form.button("villager.dialogue.tell_story");
	form.button("villager.dialogue.tell_joke");
	if (relationship >= 15) {
		form.button("villager.dialogue.flirt");
	}
	if (relationship >= 15 && flirt_count >= 5) {
		form.button("villager.dialogue.ask_out");
	}
	if (relationship >= 15 && flirt_count >= 5 && entity[0].hasTag("date_ready")) {
		form.button("villager.dialogue.start_date");
	}
	form.show(player).then(response => {
		if (response.selection == 0) {
			open_villager_aboutYourselfGUI(player);
		}
		if (response.selection == 1) {
			var talk_random = getRandomInt(0, 5);
			if (talk_random == 0) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.shy_talk.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.energetic_talk.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.rude_talk.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.flirty_talk.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (talk_random == 1) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.shy_talk.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.energetic_talk.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.rude_talk.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.flirty_talk.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (talk_random == 2) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.shy_talk.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.energetic_talk.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.rude_talk.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.flirty_talk.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (talk_random == 3) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.shy_talk.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.energetic_talk.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.rude_talk.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.flirty_talk.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (talk_random == 4) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.shy_talk.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.energetic_talk.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.rude_talk.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"villager.flirty_talk.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
			}
		}
		if (response.selection == 2) {
			var story_random = getRandomInt(0, 5);
			if (story_random == 0) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.story.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.story.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.story.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.story.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (story_random == 1) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.story.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.story.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.story.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.story.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (story_random == 2) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.story.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.story.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.story.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.story.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
			}
			if (story_random == 3) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.story.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.story.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.story.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.story.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (story_random == 4) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.story.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.story.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.story.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.story.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
			}
		}
		if (response.selection == 3) {
			var joke_random = getRandomInt(0, 5);
			if (joke_random == 0) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.joke.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.joke.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.joke.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.joke.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (joke_random == 1) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.joke.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.joke.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.joke.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.joke.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (joke_random == 2) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.joke.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.joke.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.joke.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.joke.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
			}
			if (joke_random == 3) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.joke.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.joke.4"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.joke.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.joke.4"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (joke_random == 4) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.joke.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.joke.5"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.joke.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.joke.5"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -1`);
					entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
				}
			}
		}
		if (response.selection == 4) {
			var flirt_random = getRandomInt(0, 3);
			if (flirt_random == 0) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.flirt.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.flirt.1"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.flirt.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.flirt.1"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (flirt_random == 1) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.flirt.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.flirt.2"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.flirt.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.flirt.2"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
			if (flirt_random == 2) {
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.flirt.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.flirt.3"}]}`);
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.flirt.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.flirt.3"}]}`)
					entity[0].runCommandAsync(`scoreboard players add @s ${player_flirt} 1`);
					entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
				}
			}
		}
		if (response.selection == 5) {
			entity[0].runCommandAsync("function ask_out");
		}
		if (response.selection == 6) {
			entity[0].runCommandAsync("function start_date");
		}
	})
};

function open_villager_aboutYourselfGUI(player) {
	let entity = player.getEntitiesFromViewDirection({maxDistance:3}).map(ray => ray.entity);
	let player_relationship = "relationship_" + player.nameTag;
	let relationship = getScore(entity[0], player_relationship);
	const form = new ActionFormData();
	form.title(entity[0].nameTag);
	if (entity[0].hasTag("energetic") && relationship <= 14) {
		form.body("energetic_villager.chatbubble.about_yourself");
	}
	if (entity[0].hasTag("energetic") && relationship >= 15) {
		form.body("energetic_villager.chatbubble.about_yourself_2");
	}
	if (entity[0].hasTag("flirty") && relationship <= 14) {
		form.body("flirty_villager.chatbubble.about_yourself");
	}
	if (entity[0].hasTag("flirty") && relationship >= 15) {
		form.body("flirty_villager.chatbubble.about_yourself_2");
	}
	if (entity[0].hasTag("rude")&& relationship <= 14) {
		form.body("rude_villager.chatbubble.about_yourself");
	}
	if (entity[0].hasTag("rude")&& relationship >= 15) {
		form.body("rude_villager.chatbubble.about_yourself_2");
	}
	if (entity[0].hasTag("shy") && relationship <= 14) {
		form.body("shy_villager.chatbubble.about_yourself");
	}
	if (entity[0].hasTag("shy") && relationship >= 15) {
		form.body("shy_villager.chatbubble.about_yourself_2");
	}
	form.button("villager.dialogue.favorite_food");
	form.button("villager.dialogue.favorite_color");
	form.button("villager.dialogue.favorite_biome");
	form.show(player).then(response => {
		if (response.selection == 0) {
			entity[0].runCommandAsync("function favorite_food");
			entity[0].runCommandAsync(`say ${relationship}`);
		}
		if (response.selection == 1) {
			entity[0].runCommandAsync("function favorite_color");
		}
		if (response.selection == 2) {
			entity[0].runCommandAsync("function favorite_biome");
		}
	})
};

export function open_wandering_traderGUI(player) {
	let entity = player.getEntitiesFromViewDirection({maxDistance:3}).map(ray => ray.entity);
	const form = new ActionFormData();
	form.title(entity[0].nameTag);
	form.body("villager.chatbubble.2");
	form.button("villager.dialogue.talk");
	form.button("villager.dialogue.trade");
	form.show(player).then(response => {
		if (response.selection == 0) {
			entity[0].runCommandAsync("function talk_wandering_trader");
		}
		if (response.selection == 1) {
			entity[0].runCommandAsync("function trade");
		}
	})
};

export function open_edit_villagerGUI(player) {
	let entity = player.getEntitiesFromViewDirection({maxDistance:3}).map(ray => ray.entity);
	let player_relationship = "relationship_" + player.nameTag;
	let player_flirt = "flirt_" + player.nameTag;
	const relationship = getScore(entity[0], player_relationship);
	const flirt_count = getScore(entity[0], player_flirt);
	let villager_name = entity[0].nameTag;
	let default_personality = 0;
	if (!world.scoreboard.getObjective(player_relationship)) {
		world.scoreboard.addObjective(player_relationship, player_relationship);
	}
	if (!world.scoreboard.getObjective(player_flirt)) {
		world.scoreboard.addObjective(player_flirt, player_flirt);
	}
	if (entity[0].hasTag("energetic")) {
		default_personality = 0;
	}
	if (entity[0].hasTag("flirty")) {
		default_personality = 1;
	}
	if (entity[0].hasTag("rude")) {
		default_personality = 2;
	}
	if (entity[0].hasTag("shy")) {
		default_personality = 3;
	}
	const form = new ModalFormData();
	form.title("Edit Villager");
	form.textField("Name", villager_name, villager_name);
	form.slider("Relationship Count", 0, 100, 1, relationship);
	form.slider("Flirt Count", 0, 100, 1, flirt_count);
	form.dropdown("Personality", [ "Energetic", "Flirty", "Rude", "Shy" ], default_personality);
	form.show(player).then(response => {
		if (response.isCanceled) return;
		let [ set_villager_name, set_relationship_count, set_flirt_count, set_personality ] = response.formValues;
		entity[0].nameTag = set_villager_name;
		entity[0].runCommandAsync(`scoreboard players set @s ${player_flirt} ${set_flirt_count}`);
		entity[0].runCommandAsync(`scoreboard players set @s ${player_relationship} ${set_relationship_count}`);
		entity[0].removeTag("shy");
		entity[0].removeTag("flirty");
		entity[0].removeTag("energetic");
		entity[0].removeTag("rude");
		if (set_personality == 0){
			entity[0].addTag("energetic");
		}
		if (set_personality == 1){
			entity[0].addTag("flirty");
		}
		if (set_personality == 2){
			entity[0].addTag("rude");
		}
		if (set_personality == 3){
			entity[0].addTag("shy");
		}
	})
};
